/* 
   Name:    Emote
   Version: v2a - minor changes made by Thorlack 
            <thorlack (at) moonpoint.com> to 
            v2 script by CMonkey123
	    
   Last modified: August 29, 2005
   
  See http://support.moonpoint.com/downloads/windows/games/runuo/scripts 
  for updates to this script and for other RunUO scripts

  Description: This script will allow one to issue the command "emote" to bring
  up a menu of emotions for a character to display. Alternatively, a player can
  use "e" to issue a command to display a specific emotion, e.g. "e giggle". 
  The souncs played will be match the players gender, i.e. a laugh will sound 
  female, if the character is female.
*/ 

/*
v2 changes:
	-Shortened script
	-Added emotes (thanks to zire):
		bow, faint, punch, slap, stickouttongue, tapfoot
	-Added emote gump (thanks to zire)
v2a changes:
        - Changed all occurrences of "yea" to "yeah"
        - Changed all occurrences of "wistle" to "whistle"
        - Changed all occurrences of "emenu" to "emote" so players can use 
	 "emote" rather than "emenu" to bring up the menu of emotions and 
	 actions.
        - Changed the sound for the female laugh to be the same as the sound 
	  for a female, since the code, number 801, for the female laugh 
	  doesn't produce a laugh.
        - The emote menu had a "laughs" entry, but you had to use "[e laugh" 
	  rather than "[e laughs", if you wanted to have a character laugh by 
	  issuing an "e" command.  Now either "[e laugh" or "[e laughs" will 
	  work.
        - Corrected the clearthroat codes so that a throat clearing sound is 
	  played when "[e clearthroat" is used rather than an "applauds" sound.
	  Also corrected the text displayed to state "*clears throat*" rather 
	  than "*applauds*"
*/

using System;
using System.Collections;
using System.IO;
using System.Text;
using Server;
using Server.Items;
using Server.Mobiles;
using Server.Network;

namespace Server.Scripts.Commands
{
	public class Emote
	{	
		public static void Initialize()
		{
			Server.Commands.Register( "e", AccessLevel.Player, new CommandEventHandler( Emote_OnCommand ) );
		}

	  	[Usage( "<sound>" )] 
      	[Description( "Emote with sounds, words, and possibly an animation with one command!")] 
		public static void Emote_OnCommand( CommandEventArgs e )
		{
			Mobile pm = e.Mobile;
         	string em = e.ArgString.Trim();
			
			switch( em )
			{
				case "ah":
					pm.PlaySound( pm.Female ? 778 : 1049 );
					pm.Say( "*ah!*" );
					break;
					
				case "ahha":
					pm.PlaySound( pm.Female ? 779 : 1050 );
					pm.Say( "*ah ha!*" );
					break;
					
				case "applaud":
					pm.PlaySound( pm.Female ? 780 : 1051 );
					pm.Say( "*applauds*" );
					break;
				
				case "blownose":
					pm.PlaySound( pm.Female ? 781 : 1052 );
					pm.Say( "*blows nose*" );				
					if ( !pm.Mounted )
					{
						pm.Animate( 34, 5, 1, true, false, 0 );
					}
					break;
					
				case "bow":
					pm.Say( "*bows*" );
					if ( !pm.Mounted )
					{
						pm.Animate( 32, 5, 1, true, false, 0 );
					}
					break;
					
				case "burp":
					pm.PlaySound( pm.Female ? 782 : 1053 );
					pm.Say( "*burp!*" );
					if ( !pm.Mounted )
					{	
						pm.Animate( 33, 5, 1, true, false, 0 );
					}
					break;
					
				case "woohoo":
					pm.PlaySound( pm.Female ? 783 : 1054 );
					pm.Say( "*woohoo!*" );
					break;
					
				case "clearthroat":
					pm.PlaySound( pm.Female ? 784 : 1055 );
					pm.Say( "*clears throat*" );
					break;
					
				case "cough":
					pm.PlaySound( pm.Female ? 785 : 1056 );
					pm.Say( "*cough!*" );				
					if ( !pm.Mounted )
					{
						pm.Animate( 33, 5, 1, true, false, 0 );
					}
					break;

				case "bscough":
					pm.PlaySound( pm.Female ? 786 : 1057 );
					pm.Say( "*bs cough*" );
					break;
					
				case "cry":
					pm.PlaySound( pm.Female ? 787 : 1058 );
					pm.Say( "*cries*" );
					break;
					
				case "faint":					
					pm.PlaySound( pm.Female ? 791 : 1063 );
					pm.Say( "*faints*" );
					if ( !pm.Mounted )
					{
						pm.Animate( 22, 5, 1, true, false, 0 );
					}
					break;
					
				case "fart":
					pm.PlaySound( pm.Female ? 792 : 1064 );
					pm.Say( "*farts*" );
					break;
										
				case "gasp":
					pm.PlaySound( pm.Female ? 793 : 1065 );
					pm.Say( "*gasp!*" );
					break;
				
				case "giggle":
					pm.PlaySound( pm.Female ? 794 : 1066 );
					pm.Say( "*giggles*" );
					break;

				case "groan":
					pm.PlaySound( pm.Female ? 795 : 1067 );
					pm.Say( "*groans*" );
					break;
				
				case "growl":
					pm.PlaySound( pm.Female ? 796 : 1068 );
					pm.Say( "*growls*" );
					break;
					
				case "hey":
					pm.PlaySound( pm.Female ? 797 : 1069 );
					pm.Say( "*hey!*" );
					break;
					
				case "hiccup":
					pm.PlaySound( pm.Female ? 798 : 1070 );
					pm.Say( "*hiccup!*" );
					break;
					
				case "huh":
					pm.PlaySound( pm.Female ? 799 : 1071 );
					pm.Say( "*huh?*" );
					break;

				case "kiss":
					pm.PlaySound( pm.Female ? 800 : 1072 );
					pm.Say( "*kisses*" );
					break;
					
				case "laugh":
					pm.PlaySound( pm.Female ? 794 : 1073 );
					pm.Say( "*laughs*" );
					break;
                                
                                case "laughs":
	                                goto case "laugh";				

				case "no":
					pm.PlaySound( pm.Female ? 802 : 1074 );
					pm.Say( "*no!*" );
					break;
					
				case "oh":
					pm.PlaySound( pm.Female ? 803 : 1075 );
					pm.Say( "*oh!*" );
					break;
					
				case "oooh":
					pm.PlaySound( pm.Female ? 811 : 1085 );
					pm.Say( "*oooh*" );
					break;
			
				case "oops":
					pm.PlaySound( pm.Female ? 812 : 1086 );
					pm.Say( "*oops*" );
					break;
					
				case "puke":
					pm.PlaySound( pm.Female ? 813 : 1087 );
					pm.Say( "*pukes*" );
            		if ( !pm.Mounted ) 
            		{ 
              			pm.Animate( 32, 5, 1, true, false, 0 ); 
            		} 
            		Point3D p = new Point3D( pm.Location ); 
            		switch( pm.Direction ) 
            		{ 
               			case Direction.North: 
							p.Y--; break;							 
               			case Direction.South: 
							p.Y++; break;							 
               			case Direction.East: 
                  			p.X++; break;							 
               			case Direction.West: 
                  			p.X--; break; 							
               			case Direction.Right: 
                  			p.X++; p.Y--; break;							        
               			case Direction.Down: 
                  			p.X++; p.Y++; break;							  
               			case Direction.Left: 
                  			p.X--; p.Y++; break; 							
               			case Direction.Up: 
                  			p.X--; p.Y--; break; 							
               			default: 
                  			break; 
					} 
           		 	p.Z = pm.Map.GetAverageZ( p.X, p.Y ); 
                    
            		Puke puke = new Puke(); 
            		puke.Map = pm.Map; 
            		puke.Location = p; 
					break;
					
				case "punch": 					
					pm.PlaySound( 315 );
					pm.Say( "*punches*" );
					if ( !pm.Mounted )
					{
						pm.Animate( 31, 5, 1, true, false, 0 );
					}
					break;

					
				case "scream":
					pm.PlaySound( pm.Female ? 814 : 1088 );
					pm.Say( "*ahhhh!*" );
					break;
				
				case "shush":
					pm.PlaySound( pm.Female ? 815 : 1089 );
					pm.Say( "*shhh!*" );
					break;
					
				case "sigh":
					pm.PlaySound( pm.Female ? 816 : 1090 );
					pm.Say( "*sigh*" );
					break;
					
				case "slap":
				{
					pm.PlaySound( 948 );
					pm.Say( "*slaps*" );
					if ( !pm.Mounted )
					{
						pm.Animate( 11, 5, 1, true, false, 0 );
					}
					break;
				}
					
				case "sneeze":
					pm.PlaySound( pm.Female ? 817 : 1091 );
					pm.Say( "*ahh-choo!*" );
					break;
					
				case "sniff":
					pm.PlaySound( pm.Female ? 818 : 1092 );
					pm.Say( "*sniff*" );
					break;
					
				case "snore":
					pm.PlaySound( pm.Female ? 819 : 1093 );
					pm.Say( "*snore*" );
					break;
					
				case "spit":
					pm.PlaySound( pm.Female ? 820 : 1094 );
					pm.Say( "*spits*" );
					break;
					
				case "stickouttongue":
				{
					pm.PlaySound( 792 );
					pm.Say( "*sticks out tongue*" );
					break;
				}

				case "tapfoot":
					pm.PlaySound( 874 );
					pm.Say( "*taps foot*" );
					if ( !pm.Mounted )
					{
						pm.Animate( 38, 5, 1, true, false, 0 );
					}
					break;
					
				case "whistle":
					pm.PlaySound( pm.Female ? 821 : 1095 );	
					pm.Say( "*whistles*" );
					break;
					
				case "yawn":
					pm.PlaySound( pm.Female ? 822 : 1096 );
					pm.Say( "*yawns*" );
					break;
				
				case "yeah":
					pm.PlaySound( pm.Female ? 823 : 1097 );
					pm.Say( "*yeah!*" );
					break;
				
				case "yell":
					pm.PlaySound( pm.Female ? 823 : 1098 );
					pm.Say( "*yells*" );
					break;
			}
		}
	}
}

//puke item
namespace Server.Items 
{ 
   public class ItemRemovalTimer : Timer 
   { 
      private Item i_item; 

      public ItemRemovalTimer( Item item ) : base( TimeSpan.FromSeconds( 2.0 ) ) 
      { 
         Priority = TimerPriority.OneSecond; 
         i_item = item; 
      } 

      protected override void OnTick() 
      { 
         if (( i_item != null ) && ( !i_item.Deleted )) 
            i_item.Delete(); 
      } 
   } 

   public class Puke : Item 
   { 
      [Constructable] 
      public Puke() : base( Utility.RandomList( 0xf3b, 0xf3c ) ) 
      { 
         Name = "A Pile of Puke"; 
         Hue = 0x557; 
         Movable = false; 

         ItemRemovalTimer thisTimer = new ItemRemovalTimer( this ); 
         thisTimer.Start(); 

      } 

      public override void OnSingleClick( Mobile from ) 
      { 
         this.LabelTo( from, this.Name ); 
      } 
  
      public Puke( Serial serial ) : base( serial ) 
      { 
      } 

      public override void Serialize(GenericWriter writer) 
      { 
         base.Serialize( writer ); 
         writer.Write( (int) 0 ); 
      } 

      public override void Deserialize(GenericReader reader) 
      { 
         base.Deserialize( reader ); 
         int version = reader.ReadInt(); 

         this.Delete(); // none when the world starts 
      } 
   } 
}

//emote gump thanks to zire
namespace Server.Gumps
{
	public enum EmotePage 
	{ 
	P1,
	P2,
	P3,
	P4,
	} 

	public class EmoteGump : Gump 
	{ 

	public static void Initialize() 
	{ 
	Commands.Register( "emote", AccessLevel.Player, new CommandEventHandler( Msg_OnCommand ) ); 
	} 

	[Usage( "emote" )] 
	[Description( "Emote Menu" )] 

	private static void Msg_OnCommand( CommandEventArgs e ) 
	{
	e.Mobile.SendGump( new EmoteGump( e.Mobile, EmotePage.P1) );
	} 

	private Mobile m_From; 
	private EmotePage m_Page; 

	private const int Blanco = 0xFFFFFF; 
	private const int Azul = 0x8080FF; 

	public void AddPageButton( int x, int y, int buttonID, string text, EmotePage page, params EmotePage[] subpage ) 
	{ 
	bool seleccionado = ( m_Page == page ); 
	for ( int i = 0; !seleccionado && i < subpage.Length; ++i ) 
	seleccionado = ( m_Page == subpage[i] ); 
	AddButton( x, y - 1, seleccionado ? 4006 : 4005, 4007, buttonID, GumpButtonType.Reply, 0 ); 
	AddHtml( x + 35, y, 200, 20, Color( text, seleccionado ? Azul : Blanco ), false, false ); 
	} 

	public void AddButtonLabeled( int x, int y, int buttonID, string text ) 
	{ 
	AddButton( x, y - 1, 4005, 4007, buttonID, GumpButtonType.Reply, 0 ); 
	AddHtml( x + 35, y, 240, 20, Color( text, Blanco ), false, false ); 
	} 

	public int GetButtonID( int type, int index ) 
	{ 
	return 1 + (index * 15) + type; 
	} 

	public string Color( string text, int color ) 
	{ 
	return String.Format( "<BASEFONT COLOR=#{0:X6}>{1}</BASEFONT>", color, text ); 
	} 

	public EmoteGump ( Mobile from, EmotePage page) : base ( 600, 50 ) 
	{ 
	from.CloseGump( typeof( EmoteGump ) ); 
	m_From = from; 
	m_Page = page; 
	Closable = true; 
	Dragable = true; 


	AddPage( 0 );
	AddBackground( 0, 65, 130, 360, 5054);
	AddAlphaRegion( 10, 70, 110, 350 );
	AddImageTiled( 10, 70, 110, 20, 9354);
	AddLabel( 13, 70, 200, "Emote List");
	AddImage( 100, 0, 10410);
	AddImage( 100, 305, 10412);
	AddImage( 100, 150, 10411);

	switch ( page ) 
	{

	case EmotePage.P1:
		{
		AddButtonLabeled( 10, 90, GetButtonID( 1, 1 ), "Ah");
		AddButtonLabeled( 10, 115, GetButtonID( 1, 2 ), "Ah-ha");
		AddButtonLabeled( 10, 140, GetButtonID( 1, 3 ), "Applaud");
		AddButtonLabeled( 10, 165, GetButtonID( 1, 4 ), "Blows Nose");
		AddButtonLabeled( 10, 190, GetButtonID( 1, 5 ), "Bows");
		AddButtonLabeled( 10, 215, GetButtonID( 1, 6 ), "BS Cough");
		AddButtonLabeled( 10, 240, GetButtonID( 1, 7 ), "Burp");
		AddButtonLabeled( 10, 265, GetButtonID( 1, 8 ), "Clear Throat");
		AddButtonLabeled( 10, 290, GetButtonID( 1, 9 ), "Cough");
		AddButtonLabeled( 10, 315, GetButtonID( 1, 10 ), "Cry");
		AddButtonLabeled( 10, 340, GetButtonID( 1, 11 ), "Faints");
		AddButtonLabeled( 10, 365, GetButtonID( 1, 12 ), "Fart");
		AddButton( 70, 380, 4502, 0504, GetButtonID( 0,2 ), GumpButtonType.Reply, 0 );
		}
		break; 

	case EmotePage.P2:
		{ 
		AddButtonLabeled( 10, 90, GetButtonID( 1, 13 ), "Gasp");
		AddButtonLabeled( 10, 115, GetButtonID( 1, 14 ), "Giggle");
		AddButtonLabeled( 10, 140, GetButtonID( 1, 15 ), "Groan");
		AddButtonLabeled( 10, 165, GetButtonID( 1, 16 ), "Growl");
		AddButtonLabeled( 10, 190, GetButtonID( 1, 17 ), "Hey");
		AddButtonLabeled( 10, 215, GetButtonID( 1, 18 ), "Hiccup");
		AddButtonLabeled( 10, 240, GetButtonID( 1, 19 ), "Huh");
		AddButtonLabeled( 10, 265, GetButtonID( 1, 20 ), "Kiss");
		AddButtonLabeled( 10, 290, GetButtonID( 1, 21 ), "Laughs");
		AddButtonLabeled( 10, 315, GetButtonID( 1, 22 ), "No");
		AddButtonLabeled( 10, 340, GetButtonID( 1, 23 ), "Oh");
		AddButtonLabeled( 10, 365, GetButtonID( 1, 24 ), "Oooh");
		AddButton( 10, 380, 4506, 4508, GetButtonID( 0,1 ), GumpButtonType.Reply, 0 );
		AddButton( 70, 380, 4502, 0504, GetButtonID( 0,3 ), GumpButtonType.Reply, 0 );
		break; 
		} 

	case EmotePage.P3:
		{
		AddButtonLabeled( 10, 90, GetButtonID( 1, 25 ), "Oops");
		AddButtonLabeled( 10, 115, GetButtonID( 1, 26 ), "Puke");
		AddButtonLabeled( 10, 140, GetButtonID( 1, 27 ), "Punch");
		AddButtonLabeled( 10, 165, GetButtonID( 1, 28 ), "Scream");
		AddButtonLabeled( 10, 190, GetButtonID( 1, 29 ), "Shush");
		AddButtonLabeled( 10, 215, GetButtonID( 1, 30 ), "Sigh");
		AddButtonLabeled( 10, 240, GetButtonID( 1, 31 ), "Slap");
		AddButtonLabeled( 10, 265, GetButtonID( 1, 32 ), "Sneeze");
		AddButtonLabeled( 10, 290, GetButtonID( 1, 33 ), "Sniff");
		AddButtonLabeled( 10, 315, GetButtonID( 1, 34 ), "Snore");
		AddButtonLabeled( 10, 340, GetButtonID( 1, 35 ), "Spit");
		AddButtonLabeled( 10, 365, GetButtonID( 1, 36 ), "Sticks Tongue");
		AddButton( 10, 380, 4506, 4508, GetButtonID( 0,2 ), GumpButtonType.Reply, 0 );
		AddButton( 70, 380, 4502, 0504, GetButtonID( 0,4 ), GumpButtonType.Reply, 0 );
		break; 
		} 

	case EmotePage.P4:
		{
		AddButtonLabeled( 10, 90, GetButtonID( 1, 37 ), "Taps Foot");
		AddButtonLabeled( 10, 115, GetButtonID( 1, 38 ), "Whistle");
		AddButtonLabeled( 10, 140, GetButtonID( 1, 39 ), "Woohoo");
		AddButtonLabeled( 10, 165, GetButtonID( 1, 40 ), "Yawn");
		AddButtonLabeled( 10, 190, GetButtonID( 1, 41 ), "Yeah");
		AddButtonLabeled( 10, 215, GetButtonID( 1, 42 ), "Yell");
		AddButton( 10, 380, 4506, 4508, GetButtonID( 0,3 ), GumpButtonType.Reply, 0 );
		break; 
		} 
         } 
      } 

	public override void OnResponse( Server.Network.NetState sender, RelayInfo info ) 
		{ 
		int val = info.ButtonID - 1; 

		if ( val < 0 ) 
		return; 

		Mobile from = m_From;

		int type = val % 15; 
		int index = val / 15; 

		switch ( type )
		{
	case 0:
		{
		EmotePage page;

		switch ( index )
		{
	case 1: page = EmotePage.P1; break;
	case 2: page = EmotePage.P2; break;
	case 3: page = EmotePage.P3; break;
	case 4: page = EmotePage.P4; break;
		default: return;
		}

		from.SendGump( new EmoteGump( from, page) );
		break;
		}

	case 1:
		{
		switch ( index )
		{

	case 1:
		{
		if ( from.Female ) 
		{
		from.PlaySound( 778 );
		from.Say( "*ah!*" );
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1049 );
		from.Say( "*ah!*" );
		}
		from.SendGump( new EmoteGump( from, EmotePage.P1) );
		break;
		}

	case 2:
		{
		if ( from.Female )
		{
		from.PlaySound( 779 );
		from.Say( "*ah-ha!*" );
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1050 );
		from.Say( "*ah-ha!*" );
		}
		from.SendGump( new EmoteGump( from, EmotePage.P1) );
		break;
		}

	case 3:
		{
		if ( from.Female )
		{
		from.PlaySound( 780 );
		from.Say( "*applauds*" );
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1051 );
		from.Say( "*applauds*" );
		}
		from.SendGump( new EmoteGump( from, EmotePage.P1) );
		break;
		}

	case 4:
		{
		if ( from.Female )
		{
		from.PlaySound( 781 );
		from.Say( "*blows nose*" );
		if ( !from.Mounted )
		{
		from.Animate( 34, 5, 1, true, false, 0 );
		}
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1052 );
		from.Say( "*blows nose*" );
		if ( !from.Mounted )
		{
		from.Animate( 34, 5, 1, true, false, 0 );
		}
		}
		from.SendGump( new EmoteGump( from, EmotePage.P1) );
		break;
		}

	case 5:
		{
		from.Say( "*bows*" );
		if ( !from.Mounted )
		{
		from.Animate( 32, 5, 1, true, false, 0 );
		}
		from.SendGump( new EmoteGump( from, EmotePage.P1) );
		break;
		}

	case 6:
		{
		if ( from.Female )
		{
		from.PlaySound( 786 );
		from.Say( "*bs cough*" );
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1057 );
		from.Say( "*bs cough*" );
		}
		from.SendGump( new EmoteGump( from, EmotePage.P1) );
		break;
		}

	case 7:
		{
		if ( from.Female )
		{
		from.PlaySound( 782 );
		from.Say( "*burp!*" );
		if ( !from.Mounted )
		{
		from.Animate( 33, 5, 1, true, false, 0 );
		}
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1053 );
		from.Say( "*burp!*" );
		if ( !from.Mounted )
		{
		from.Animate( 33, 5, 1, true, false, 0 );
		}
		}
		from.SendGump( new EmoteGump( from, EmotePage.P1) );
		break;
		}

	case 8:
		{
		if ( from.Female )
		{
		from.PlaySound( 784 );
		from.Say( "*clears throat*" );

		if ( !from.Mounted )
		{
		from.Animate( 33, 5, 1, true, false, 0 );
		}
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1055 );
		from.Say( "*clears throat*" );
		if ( !from.Mounted )
		{
		from.Animate( 33, 5, 1, true, false, 0 );
		}
		}
		from.SendGump( new EmoteGump( from, EmotePage.P1) );
		break;
		}

	case 9:
		{
		if ( from.Female )
		{
		from.PlaySound( 785 );
		from.Say( "*cough!*" );
		if ( !from.Mounted )
		{
		from.Animate( 33, 5, 1, true, false, 0 );
		}
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1056 );
		from.Say( "*cough!*" );
		if ( !from.Mounted )
		{
		from.Animate( 33, 5, 1, true, false, 0 );
		}
		}
		from.SendGump( new EmoteGump( from, EmotePage.P1) );
		break;
		}

	case 10:
		{
		if ( from.Female )
		{
		from.PlaySound( 787 );
		from.Say( "*cries*" );
		if ( !from.Mounted )
		{
		from.Animate( 34, 5, 1, true, false, 0 );
		}
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1058 );
		from.Say( "*cries*" );
		if ( !from.Mounted )
		{
		from.Animate( 34, 5, 1, true, false, 0 );
		}
		}
		from.SendGump( new EmoteGump( from, EmotePage.P1) );
		break;
		}

	case 11:
		{
		if ( from.Female )
		{
		from.PlaySound( 791 );
		from.Say( "*faints*" );
		if ( !from.Mounted )
		{
		from.Animate( 22, 5, 1, true, false, 0 );
		}
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1063 );
		from.Say( "*faints*" );
		if ( !from.Mounted )
		{
		from.Animate( 22, 5, 1, true, false, 0 );
		}
		}
		from.SendGump( new EmoteGump( from, EmotePage.P1) );
		break;
		}

	case 12:
		{
		if ( from.Female )
		{
		from.PlaySound( 792 );
		from.Say( "*farts*" );
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1064 );
		from.Say( "*farts*" );
		}
		from.SendGump( new EmoteGump( from, EmotePage.P1) );
		break;
		}

	case 13:
		{
		if ( from.Female )
		{
		from.PlaySound( 793 );
		from.Say( "*gasp!*" );
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1065 );
		from.Say( "*gasp!*" );
		}
		from.SendGump( new EmoteGump( from, EmotePage.P2) );
		break;
		}

	case 14:
		{
		if ( from.Female )
		{
		from.PlaySound( 794 );
		from.Say( "*giggles*" );
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1066 );
		from.Say( "*giggles*" );
		}
		from.SendGump( new EmoteGump( from, EmotePage.P2) );
		break;
		}

	case 15:
		{
		if ( from.Female )
		{
		from.PlaySound( 795 );
		from.Say( "*groans*" );
		if ( !from.Mounted )
		{
		from.Animate( 6, 5, 1, true, false, 0 );
		}
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1067 );
		from.Say( "*groans*" );
		if ( !from.Mounted )
		{
		from.Animate( 6, 5, 1, true, false, 0 );
		}
		}
		from.SendGump( new EmoteGump( from, EmotePage.P2) );
		break;
		}

	case 16:
		{
		if ( from.Female )
		{
		from.PlaySound( 796 );
		from.Say( "*growls*" );
		if ( !from.Mounted )
		{
		from.Animate( 6, 5, 1, true, false, 0 );
		}
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1068 );
		from.Say( "*growls*" );
		if ( !from.Mounted )
		{
		from.Animate( 6, 5, 1, true, false, 0 );
		}
		}
		from.SendGump( new EmoteGump( from, EmotePage.P2) );
		break;
		}

	case 17:
		{
		if ( from.Female )
		{
		from.PlaySound( 797 );
		from.Say( "*hey!*" );
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1069 );
		from.Say( "*hey!*" );
		}
		from.SendGump( new EmoteGump( from, EmotePage.P2) );
		break;
		}

	case 18:
		{
		if ( from.Female )
		{
		from.PlaySound( 798 );
		from.Say( "*hiccup!*" );
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1070 );
		from.Say( "*hiccup!*" );
		}
		from.SendGump( new EmoteGump( from, EmotePage.P2) );
		break;
		}

	case 19:
		{
		if ( from.Female )
		{
		from.PlaySound( 799 );
		from.Say( "*huh?*" );
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1071 );
		from.Say( "*huh?*" );
		}
		from.SendGump( new EmoteGump( from, EmotePage.P2) );
		break;
		}

	case 20:
		{
		if ( from.Female )
		{
		from.PlaySound( 800 );
		from.Say( "*kisses*" );
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1072 );
		from.Say( "*kisses*" );
		}
		from.SendGump( new EmoteGump( from, EmotePage.P2) );
		break;
		}

	case 21:
		{
		if ( from.Female )
		{
		from.PlaySound( 794 );
		from.Say( "*laughs!*" );
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1073 );
		from.Say( "*laughs!*" );
		}
		from.SendGump( new EmoteGump( from, EmotePage.P2) );
		break;
		}

	case 22:
		{
		if ( from.Female )
		{
		from.PlaySound( 802 );
		from.Say( "*no!*" );
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1074 );
		from.Say( "*no!*" );
		}
		from.SendGump( new EmoteGump( from, EmotePage.P2) );
		break;
		}

	case 23:
		{
		if ( from.Female )
		{
		from.PlaySound( 803 );
		from.Say( "*oh!*" );
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1075 );
		from.Say( "*oh!*" );
		}
		from.SendGump( new EmoteGump( from, EmotePage.P2) );
		break;
		}

	case 24:
		{
		if ( from.Female )
		{
		from.PlaySound( 811 );
		from.Say( "*oooh!*" );
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1085 );
		from.Say( "*oooh!*" );
		}
		from.SendGump( new EmoteGump( from, EmotePage.P2) );
		break;
		}

	case 25:
		{
		if ( from.Female )
		{
		from.PlaySound( 812 );
		from.Say( "*oops!*" );
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1086 );
		from.Say( "*oops!*" );
		}
		from.SendGump( new EmoteGump( from, EmotePage.P3) );
		break;
		}

	case 26:
		{ 
		if ( from.Female )
		{
		from.PlaySound(  813 ); 
		from.Say( "*pukes*" ); 
		if ( !from.Mounted ) 
		{ 
		from.Animate( 32, 5, 1, true, false, 0 ); 
		} 
		}
		if ( !from.Female )
		{
		from.PlaySound(  1087 ); 
		from.Say( "*pukes*" ); 
		if ( !from.Mounted ) 
		{ 
		from.Animate( 32, 5, 1, true, false, 0 ); 
		} 
		}
		from.SendGump( new EmoteGump( from, EmotePage.P3) );
		break;
		}

	case 27:
		{
		from.PlaySound( 315 );
		from.Say( "*punches*" );
		if ( !from.Mounted )
		{
		from.Animate( 31, 5, 1, true, false, 0 );
		}
		from.SendGump( new EmoteGump( from, EmotePage.P3) );
		break;
		}

	case 28:
		{
		if ( from.Female )
		{
		from.PlaySound( 814 );
		from.Say( "*aaahh!*" );
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1088 );
		from.Say( "*aaahh!*" );
		}
		from.SendGump( new EmoteGump( from, EmotePage.P3) );
		break;
		}


	case 29:
		{
		if ( from.Female )
		{
		from.PlaySound( 815 );
		from.Say( "*shh!*" );
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1089 );
		from.Say( "*shh!*" );
		}
		from.SendGump( new EmoteGump( from, EmotePage.P3) );
		break;
		}

	case 30:
		{
		if ( from.Female )
		{
		from.PlaySound( 816 );
		from.Say( "*sigh*" );
		if ( !from.Mounted )
		{
		from.Animate( 6, 5, 1, true, false, 0 );
		}
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1090 );
		from.Say( "*sigh*" );
		if ( !from.Mounted )
		{
		from.Animate( 6, 5, 1, true, false, 0 );
		}
		}
		from.SendGump( new EmoteGump( from, EmotePage.P3) );
		break;
		}

	case 31:
		{
		from.PlaySound( 948 );
		from.Say( "*slaps*" );
		if ( !from.Mounted )
		{
		from.Animate( 11, 5, 1, true, false, 0 );
		}
		from.SendGump( new EmoteGump( from, EmotePage.P3) );
		break;
		}

	case 32:
		{
		if ( from.Female )
		{
		from.PlaySound( 817 );
		from.Say( "*ahh-choo!*" );
		if ( !from.Mounted )
		{
		from.Animate( 32, 5, 1, true, false, 0 );
		}
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1091 );
		from.Say( "*ahh-choo!*" );
		if ( !from.Mounted )
		{
		from.Animate( 32, 5, 1, true, false, 0 );
		}
		}
		from.SendGump( new EmoteGump( from, EmotePage.P3) );
		break;
		}

	case 33:
		{
		if ( from.Female )
		{
		from.PlaySound( 818 );
		from.Say( "*sniff*" );
		if ( !from.Mounted )
		{
		from.Animate( 34, 5, 1, true, false, 0 );
		}
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1092 );
		from.Say( "*sniff*" );
		if ( !from.Mounted )
		{
		from.Animate( 34, 5, 1, true, false, 0 );
		}
		}
		from.SendGump( new EmoteGump( from, EmotePage.P3) );
		break;
		}

	case 34:
		{
		if ( from.Female )
		{
		from.PlaySound( 819 );
		from.Say( "*snore*" );
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1093 );
		from.Say( "*snore*" );
		}
		from.SendGump( new EmoteGump( from, EmotePage.P3) );
		break;
		}

	case 35:
		{
		if ( from.Female )
		{
		from.PlaySound( 820 );
		from.Say( "*spits*" );
		if ( !from.Mounted )
		{
		from.Animate( 6, 5, 1, true, false, 0 );
		}
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1094 );
		from.Say( "*spits*" );
		if ( !from.Mounted )
		{
		from.Animate( 6, 5, 1, true, false, 0 );
		}
		}
		from.SendGump( new EmoteGump( from, EmotePage.P3) );
		break;
		}

	case 36:
		{
		from.PlaySound( 792 );
		from.Say( "*sticks out tongue*" );
		from.SendGump( new EmoteGump( from, EmotePage.P3) );
		break;
		}

	case 37:
		{
		from.PlaySound( 874 );
		from.Say( "*taps foot*" );
		if ( !from.Mounted )
		{
		from.Animate( 38, 5, 1, true, false, 0 );
		}
		from.SendGump( new EmoteGump( from, EmotePage.P4) );
		break;
		}

	case 38:
		{
		if ( from.Female )
		{
		from.PlaySound( 821 );
		from.Say( "*whistles*" );
		if ( !from.Mounted )
		{
		from.Animate( 5, 5, 1, true, false, 0 );
		}
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1095 );
		from.Say( "*whistles*" );
		if ( !from.Mounted )
		{
		from.Animate( 5, 5, 1, true, false, 0 );
		}
		}
		from.SendGump( new EmoteGump( from, EmotePage.P4) );
		break;
		}

	case 39:
		{
		if ( from.Female )
		{
		from.PlaySound( 783 );
		from.Say( "*woohoo!*" );
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1054 );
		from.Say( "*woohoo!*" );
		}
		from.SendGump( new EmoteGump( from, EmotePage.P4) );
		break;
		}

	case 40:
		{
		if ( from.Female )
		{
		from.PlaySound( 822 );
		from.Say( "*yawn*" );
		if ( !from.Mounted )
		{
		from.Animate( 17, 5, 1, true, false, 0 );
		}
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1096 );
		from.Say( "*yawn*" );
		if ( !from.Mounted )
		{
		from.Animate( 17, 5, 1, true, false, 0 );
		}
		}
		from.SendGump( new EmoteGump( from, EmotePage.P4) );
		break;
		}

	case 41:
		{
		if ( from.Female )
		{
		from.PlaySound( 823 );
		from.Say( "*yeah!*" );
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1097 );
		from.Say( "*yeah!*" );
		}
		from.SendGump( new EmoteGump( from, EmotePage.P4) );
		break;
		}

	case 42:
		{
		if ( from.Female )
		{
		from.PlaySound( 824 );
		from.Say( "*yells*" );
		}
		else if ( !from.Female )
		{
		from.PlaySound( 1098 );
		from.Say( "*yells*" );
		}
		from.SendGump( new EmoteGump( from, EmotePage.P4) );
		break;
		}

		} 
               break; 
            } 
         } 
      } 
   }
}

